package gmodel

import (
	"context"
	"errors"
	"gorm.io/gorm"
)

type FsTags struct {
	Id                   int64   `gorm:"primary_key" json:"id"`                    // ID
	Title                *string `gorm:"default:''" json:"title"`                  // 标题
	Level                *int64  `gorm:"default:0" json:"level"`                   // 层级、分类 1 => 二维码分类
	ClickNum             *int64  `gorm:"default:0" json:"click_num"`               // 点击次数
	Sort                 *int64  `gorm:"default:0" json:"sort"`                    // 排序(从大到小)
	CreateAt             *int64  `gorm:"default:0" json:"create_at"`               // 创建时间
	Icon                 *string `gorm:"default:''" json:"icon"`                   // 标签图标
	Status               *int64  `gorm:"default:1" json:"status"`                  // 状态 1：可用
	Description          *string `gorm:"default:''" json:"description"`            // 介绍 Seo
	RecommendProduct     *string `gorm:"default:''" json:"recommend_product"`      // 推荐产品id例如: 1,3,4,5
	RecommendProductSort *string `gorm:"default:''" json:"recommend_product_sort"` // 推荐排序例如:1324
}
type FsTagsModel struct {
	db *gorm.DB
}

func NewFsTagsModel(db *gorm.DB) *FsTagsModel {
	return &FsTagsModel{db}
}
func (t *FsTagsModel) FindOne(ctx context.Context, id int64) (resp FsTags, err error) {
	err = t.db.WithContext(ctx).Model(&FsTags{}).Where("`id` = ? and `status` = ?", id, 1).First(&resp).Error
	if err != nil && !errors.Is(err, gorm.ErrRecordNotFound) {
		return FsTags{}, err
	}
	return
}
func (t *FsTagsModel) GetAllByIds(ctx context.Context, ids []int64) (resp []FsTags, err error) {
	err = t.db.WithContext(ctx).Model(&FsTags{}).Where("`id` in(?) and `status` = ?", ids, 1).Find(&resp).Error
	if err != nil {
		return nil, err
	}
	return
}
func (t *FsTagsModel) GetAllByLevel(ctx context.Context, level int) (resp []FsTags, err error) {
	err = t.db.Model(&FsTags{}).Where("`level` = ? and `status` = ?", level, 1).Find(&resp).Error
	if err != nil {
		return nil, err
	}
	return
}
